Rtrace
--------------------------------

.. autoclass:: raytraverse.renderer.Rtrace
    :members:
    :undoc-members:
    :show-inheritance:

Rcontrib
--------------------------------

.. autoclass:: raytraverse.renderer.Rcontrib
    :members:
    :undoc-members:
    :show-inheritance:
